@@ -6,7 +6,6 @@ import logging
 from xarray.ufuncs import isinf, isnan
 
 from nowcasting_dataset.data_sources.datasource_output import DataSourceOutput
-from nowcasting_dataset.time import make_random_time_vectors
 
 logger = logging.getLogger(__name__)
 
@@ -23,5 +22,5 @@ class NWP(DataSourceOutput):
     def model_validation(cls, v):
         """ Check that all values are not NaNs """
         assert (~isnan(v.data)).all(), "Some nwp data values are NaNs"
-        assert (~isinf(v.data)).all(), f"Some nwp data values are Infinite"
+        assert (~isinf(v.data)).all(), "Some nwp data values are Infinite"
         return v
